@@ -6,21 +6,21 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/mickael-menu/zk/internal/adapter/editor"
-	"github.com/mickael-menu/zk/internal/adapter/fs"
-	"github.com/mickael-menu/zk/internal/adapter/fzf"
-	"github.com/mickael-menu/zk/internal/adapter/handlebars"
-	hbhelpers "github.com/mickael-menu/zk/internal/adapter/handlebars/helpers"
-	"github.com/mickael-menu/zk/internal/adapter/markdown"
-	"github.com/mickael-menu/zk/internal/adapter/sqlite"
-	"github.com/mickael-menu/zk/internal/adapter/term"
-	"github.com/mickael-menu/zk/internal/core"
-	"github.com/mickael-menu/zk/internal/util"
-	"github.com/mickael-menu/zk/internal/util/errors"
-	osutil "github.com/mickael-menu/zk/internal/util/os"
-	"github.com/mickael-menu/zk/internal/util/pager"
-	"github.com/mickael-menu/zk/internal/util/paths"
-	"github.com/mickael-menu/zk/internal/util/rand"
+	"github.com/zk-org/zk/internal/adapter/editor"
+	"github.com/zk-org/zk/internal/adapter/fs"
+	"github.com/zk-org/zk/internal/adapter/fzf"
+	"github.com/zk-org/zk/internal/adapter/handlebars"
+	hbhelpers "github.com/zk-org/zk/internal/adapter/handlebars/helpers"
+	"github.com/zk-org/zk/internal/adapter/markdown"
+	"github.com/zk-org/zk/internal/adapter/sqlite"
+	"github.com/zk-org/zk/internal/adapter/term"
+	"github.com/zk-org/zk/internal/core"
+	"github.com/zk-org/zk/internal/util"
+	"github.com/zk-org/zk/internal/util/errors"
+	osutil "github.com/zk-org/zk/internal/util/os"
+	"github.com/zk-org/zk/internal/util/pager"
+	"github.com/zk-org/zk/internal/util/paths"
+	"github.com/zk-org/zk/internal/util/rand"
 )
 
 type Dirs struct {
