@@ -6,10 +6,10 @@ import (
 
 	"github.com/alecthomas/kong"
 	"github.com/kballard/go-shellquote"
-	"github.com/mickael-menu/zk/internal/core"
-	dateutil "github.com/mickael-menu/zk/internal/util/date"
-	"github.com/mickael-menu/zk/internal/util/errors"
-	"github.com/mickael-menu/zk/internal/util/strings"
+	"github.com/zk-org/zk/internal/core"
+	dateutil "github.com/zk-org/zk/internal/util/date"
+	"github.com/zk-org/zk/internal/util/errors"
+	"github.com/zk-org/zk/internal/util/strings"
 )
 
 // Filtering holds filtering options to select notes.
@@ -280,7 +280,9 @@ func parseDayRange(date string) (start time.Time, end time.Time, err error) {
 		return
 	}
 
-	start = startOfDay(day)
+    // we add -1 second so that the day range ends at 23:59:59
+    // i.e, the 'new day' begins at 00:00:00
+	start = startOfDay(day).Add(time.Second * -1)
 	end = start.AddDate(0, 0, 1)
 	return start, end, nil
 }
